Index: /trunk/src/VBox/Disassembler/DisasmCore.cpp
===================================================================
--- /trunk/src/VBox/Disassembler/DisasmCore.cpp	(revision 41742)
+++ /trunk/src/VBox/Disassembler/DisasmCore.cpp	(revision 41743)
@@ -617,5 +617,5 @@
     {
          pParam->fUse |= DISUSE_INDEX | regtype;
-         pParam->index.reg_gen = index;
+         pParam->Index.idxGenReg = index;
 
          if (scale != 0)
@@ -2379,5 +2379,5 @@
     {
         pParam->fUse |= DISUSE_INDEX;
-        pParam->index.reg_gen = IndexModRMReg16[idx];
+        pParam->Index.idxGenReg = IndexModRMReg16[idx];
     }
 }
Index: /trunk/src/VBox/Disassembler/DisasmFormatYasm.cpp
===================================================================
--- /trunk/src/VBox/Disassembler/DisasmFormatYasm.cpp	(revision 41742)
+++ /trunk/src/VBox/Disassembler/DisasmFormatYasm.cpp	(revision 41743)
@@ -208,6 +208,6 @@
         case DISCPUMODE_16BIT:
         {
-            Assert(pParam->index.reg_gen < RT_ELEMENTS(g_aszYasmRegGen16));
-            const char *psz = g_aszYasmRegGen16[pParam->index.reg_gen];
+            Assert(pParam->Index.idxGenReg < RT_ELEMENTS(g_aszYasmRegGen16));
+            const char *psz = g_aszYasmRegGen16[pParam->Index.idxGenReg];
             *pcchReg = 2 + !!psz[2] + !!psz[3];
             return psz;
@@ -216,6 +216,6 @@
         case DISCPUMODE_32BIT:
         {
-            Assert(pParam->index.reg_gen < RT_ELEMENTS(g_aszYasmRegGen32));
-            const char *psz = g_aszYasmRegGen32[pParam->index.reg_gen];
+            Assert(pParam->Index.idxGenReg < RT_ELEMENTS(g_aszYasmRegGen32));
+            const char *psz = g_aszYasmRegGen32[pParam->Index.idxGenReg];
             *pcchReg = 2 + !!psz[2] + !!psz[3];
             return psz;
@@ -224,6 +224,6 @@
         case DISCPUMODE_64BIT:
         {
-            Assert(pParam->index.reg_gen < RT_ELEMENTS(g_aszYasmRegGen64));
-            const char *psz = g_aszYasmRegGen64[pParam->index.reg_gen];
+            Assert(pParam->Index.idxGenReg < RT_ELEMENTS(g_aszYasmRegGen64));
+            const char *psz = g_aszYasmRegGen64[pParam->Index.idxGenReg];
             *pcchReg = 2 + !!psz[2] + !!psz[3];
             return psz;
Index: /trunk/src/VBox/Disassembler/DisasmReg.cpp
===================================================================
--- /trunk/src/VBox/Disassembler/DisasmReg.cpp	(revision 41742)
+++ /trunk/src/VBox/Disassembler/DisasmReg.cpp	(revision 41743)
@@ -549,5 +549,5 @@
 
                 pParamVal->flags |= DISQPV_FLAG_16;
-                if (RT_FAILURE(DISFetchReg16(pCtx, pParam->index.reg_gen, &val16))) return VERR_INVALID_PARAMETER;
+                if (RT_FAILURE(DISFetchReg16(pCtx, pParam->Index.idxGenReg, &val16))) return VERR_INVALID_PARAMETER;
 
                 Assert(!(pParam->fUse & DISUSE_SCALE));   /* shouldn't be possible in 16 bits mode */
@@ -561,5 +561,5 @@
 
                 pParamVal->flags |= DISQPV_FLAG_32;
-                if (RT_FAILURE(DISFetchReg32(pCtx, pParam->index.reg_gen, &val32))) return VERR_INVALID_PARAMETER;
+                if (RT_FAILURE(DISFetchReg32(pCtx, pParam->Index.idxGenReg, &val32))) return VERR_INVALID_PARAMETER;
 
                 if (pParam->fUse & DISUSE_SCALE)
@@ -574,5 +574,5 @@
 
                 pParamVal->flags |= DISQPV_FLAG_64;
-                if (RT_FAILURE(DISFetchReg64(pCtx, pParam->index.reg_gen, &val64))) return VERR_INVALID_PARAMETER;
+                if (RT_FAILURE(DISFetchReg64(pCtx, pParam->Index.idxGenReg, &val64))) return VERR_INVALID_PARAMETER;
 
                 if (pParam->fUse & DISUSE_SCALE)

Index: /trunk/include/VBox/dis.h
===================================================================
--- /trunk/include/VBox/dis.h	(revision 41742)
+++ /trunk/include/VBox/dis.h	(revision 41743)
@@ -194,5 +194,5 @@
 /** @name 64-bit general register indexes.
  * This matches the AMD64 register encoding.  It is found used in
  * DISOPPARAM::base.reg_gen and DISOPPARAM::index.reg_gen.
  * @note  Safe to assume same values as the 16-bit and 32-bit general registers.
  * @{
@@ -218,5 +218,5 @@
 /** @name 32-bit general register indexes.
  * This matches the AMD64 register encoding.  It is found used in
  * DISOPPARAM::base.reg_gen and DISOPPARAM::index.reg_gen.
  * @note  Safe to assume same values as the 16-bit and 64-bit general registers.
  * @{
@@ -242,5 +242,5 @@
 /** @name 16-bit general register indexes.
  * This matches the AMD64 register encoding.  It is found used in
  * DISOPPARAM::base.reg_gen and DISOPPARAM::index.reg_gen.
  * @note  Safe to assume same values as the 32-bit and 64-bit general registers.
  * @{
@@ -266,5 +266,5 @@
 /** @name 8-bit general register indexes.
  * This mostly (?) matches the AMD64 register encoding.  It is found used in
  * DISOPPARAM::base.reg_gen and DISOPPARAM::index.reg_gen.
  * @{
  */
@@ -426,10 +426,12 @@
         uint8_t     reg_dbg;
     } base;
+    /** The SIB index register meaning, applicable if DISUSE_INDEX is
+     * set in fUse. */
     union
     {
-        /** DISGREG_XXX. */
-        uint8_t     reg_gen;
-    } index;
-
+        /** General register index (DISGREG_XXX), applicable if DISUSE_REG_GEN8,
+         * DISUSE_REG_GEN16, DISUSE_REG_GEN32 or DISUSE_REG_GEN64 is set in fUse. */
+        uint8_t     idxGenReg;
+    } Index;
     /** 2, 4 or 8, if DISUSE_SCALE is set in fUse. */
     uint8_t         uScale;
@@ -194,5 +194,5 @@
 /** @name 64-bit general register indexes.
  * This matches the AMD64 register encoding.  It is found used in
- * DISOPPARAM::base.reg_gen and DISOPPARAM::index.reg_gen.
+ * DISOPPARAM::base.reg_gen and DISOPPARAM::Index.idxGenReg.
  * @note  Safe to assume same values as the 16-bit and 32-bit general registers.
  * @{
@@ -218,5 +218,5 @@
 /** @name 32-bit general register indexes.
  * This matches the AMD64 register encoding.  It is found used in
- * DISOPPARAM::base.reg_gen and DISOPPARAM::index.reg_gen.
+ * DISOPPARAM::base.reg_gen and DISOPPARAM::Index.idxGenReg.
  * @note  Safe to assume same values as the 16-bit and 64-bit general registers.
  * @{
@@ -242,5 +242,5 @@
 /** @name 16-bit general register indexes.
  * This matches the AMD64 register encoding.  It is found used in
- * DISOPPARAM::base.reg_gen and DISOPPARAM::index.reg_gen.
+ * DISOPPARAM::base.reg_gen and DISOPPARAM::Index.idxGenReg.
  * @note  Safe to assume same values as the 32-bit and 64-bit general registers.
  * @{
@@ -266,5 +266,5 @@
 /** @name 8-bit general register indexes.
  * This mostly (?) matches the AMD64 register encoding.  It is found used in
- * DISOPPARAM::base.reg_gen and DISOPPARAM::index.reg_gen.
+ * DISOPPARAM::base.reg_gen and DISOPPARAM::Index.idxGenReg.
  * @{
  */